# Generated by roxygen2: do not edit by hand

S3method(plot,treedim)
export(compute.stats)
export(empirical.distributions)
export(separability)
export(test.trajectory)
import(RColorBrewer)
import(fitdistrplus)
import(igraph)
import(nFactors)
importFrom(Rcpp,evalCpp)
importFrom(Rdpack,reprompt)
importFrom(graphics,legend)
importFrom(graphics,plot)
importFrom(mlpack,emst)
importFrom(stats,cov)
importFrom(stats,dist)
importFrom(stats,plnorm)
importFrom(stats,prcomp)
importFrom(stats,rnorm)
useDynLib(TreeDimensionTest)
