# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

calcPairwiseDist <- function(centers) {
    .Call('_TreeDimensionTest_calcPairwiseDist', PACKAGE = 'TreeDimensionTest', centers)
}

calculate_mst <- function(dist_mat) {
    .Call('_TreeDimensionTest_calculate_mst', PACKAGE = 'TreeDimensionTest', dist_mat)
}

get_longest_path_statistic <- function(tree) {
    .Call('_TreeDimensionTest_get_longest_path_statistic', PACKAGE = 'TreeDimensionTest', tree)
}

tree_dimension <- function(tree) {
    .Call('_TreeDimensionTest_tree_dimension', PACKAGE = 'TreeDimensionTest', tree)
}

to_adj_mat <- function(edges) {
    .Call('_TreeDimensionTest_to_adj_mat', PACKAGE = 'TreeDimensionTest', edges)
}

get_edges <- function(mat, MST) {
    .Call('_TreeDimensionTest_get_edges', PACKAGE = 'TreeDimensionTest', mat, MST)
}

getStatistics <- function(mat, sample_size, MST, returnTree) {
    .Call('_TreeDimensionTest_getStatistics', PACKAGE = 'TreeDimensionTest', mat, sample_size, MST, returnTree)
}

computeDists <- function(data, perm, sample_size, g, MST) {
    .Call('_TreeDimensionTest_computeDists', PACKAGE = 'TreeDimensionTest', data, perm, sample_size, g, MST)
}

minSubtreeCover <- function(tree, s, labels) {
    .Call('_TreeDimensionTest_minSubtreeCover', PACKAGE = 'TreeDimensionTest', tree, s, labels)
}

